Camera

Struct Camera 

pub struct Camera { /* private fields */ }
Connected and initialized XIMEA camera.

Must be mutable to allow changing any parameters. A non-mutable Camera can be used from multiple threads or processes safely.

Implementations

Source

impl Camera

pub fn start_acquisition(self) -> Result<AcquisitionBuffer, XI_RETURN>

Starts the image acquisition on this camera

This function creates the AcquisitionBuffer and tells the camera to start streaming data to this buffer. The camera is temporarily consumed by the AcquisitionBuffer, so you can only interact with it through the AcquisitionBuffer.

Examples
    let cam = xiapi::open_device(None)?;
    let buffer = cam.start_acquisition()?;
    let image = buffer.next_image::<u8>(None)?;
    // Do something with the image;
    let cam = buffer.stop_acquisition()?;
pub fn set_roi(&mut self, roi: &Roi) -> Result<Roi, XI_RETURN>

Set the region of interest on this camera.

Return the region of interest that was actually set to the camera.

Examples
    let mut cam = xiapi::open_device(None)?;
    let roi = xiapi::Roi{
        offset_x: 100,
        offset_y: 100,
        width: 100,
        height: 100
    };
    let actual_roi = cam.set_roi(&roi)?;
pub fn roi(&self) -> Result<Roi, XI_RETURN>

Returns the current roi from this camera

pub fn counter(&mut self, counter_selector: Type) -> Result<i32, XI_RETURN>

Convenience method to read counters from the camera with a single call See also [Self.counter_selector] and [Self.counter_value]

pub fn exposure(&self) -> Result<f32, XI_RETURN>

Current exposure time in microseconds.

pub fn exposure_increment(&self) -> Result<f32, XI_RETURN>

Get the increment for the exposure parameter. See also Self::exposure()

pub fn exposure_minimum(&self) -> Result<f32, XI_RETURN>

Get the minimum for the exposure parameter. See also Self::exposure()

pub fn exposure_maximum(&self) -> Result<f32, XI_RETURN>

Get the maximum for the exposure parameter. See also Self::exposure()

pub fn set_exposure(&mut self, value: f32) -> Result<(), XI_RETURN>

Set the exposure parameter. See also Self::exposure()

pub fn exposure_burst_count(&self) -> Result<i32, XI_RETURN>

Sets the number of times of exposure in one frame.

pub fn exposure_burst_count_increment(&self) -> Result<i32, XI_RETURN>

Get the increment for the exposure_burst_count parameter. See also Self::exposure_burst_count()

pub fn exposure_burst_count_minimum(&self) -> Result<i32, XI_RETURN>

Get the minimum for the exposure_burst_count parameter. See also Self::exposure_burst_count()

pub fn exposure_burst_count_maximum(&self) -> Result<i32, XI_RETURN>

Get the maximum for the exposure_burst_count parameter. See also Self::exposure_burst_count()

pub fn set_exposure_burst_count(&mut self, value: i32) -> Result<(), XI_RETURN>

Set the exposure_burst_count parameter. See also Self::exposure_burst_count()

pub fn gain(&self) -> Result<f32, XI_RETURN>

Set the gain in dB. If the camera has more than one type of gain, you can use Self::set_gain_selector() to select a gain.

pub fn gain_increment(&self) -> Result<f32, XI_RETURN>

Get the increment for the gain parameter. See also Self::gain()

pub fn gain_minimum(&self) -> Result<f32, XI_RETURN>

Get the minimum for the gain parameter. See also Self::gain()

pub fn gain_maximum(&self) -> Result<f32, XI_RETURN>

Get the maximum for the gain parameter. See also Self::gain()

pub fn set_gain(&mut self, value: f32) -> Result<(), XI_RETURN>

Set the gain parameter. See also Self::gain()

pub fn gain_selector(&self) -> Result<Type, XI_RETURN>

The currently selected type of gain for Self::gain() and Self::set_gain()

pub fn gain_selector_increment(&self) -> Result<Type, XI_RETURN>

Get the increment for the gain_selector parameter. See also Self::gain_selector()

pub fn gain_selector_minimum(&self) -> Result<Type, XI_RETURN>

Get the minimum for the gain_selector parameter. See also Self::gain_selector()

pub fn gain_selector_maximum(&self) -> Result<Type, XI_RETURN>

Get the maximum for the gain_selector parameter. See also Self::gain_selector()

pub fn set_gain_selector(&mut self, value: Type) -> Result<(), XI_RETURN>

Set the gain_selector parameter. See also Self::gain_selector()

pub fn downsampling(&self) -> Result<Type, XI_RETURN>

Changes image resolution by binning or skipping

pub fn downsampling_increment(&self) -> Result<Type, XI_RETURN>

Get the increment for the downsampling parameter. See also Self::downsampling()

pub fn downsampling_minimum(&self) -> Result<Type, XI_RETURN>

Get the minimum for the downsampling parameter. See also Self::downsampling()

pub fn downsampling_maximum(&self) -> Result<Type, XI_RETURN>

Get the maximum for the downsampling parameter. See also Self::downsampling()

pub fn set_downsampling(&mut self, value: Type) -> Result<(), XI_RETURN>

Set the downsampling parameter. See also Self::downsampling()

pub fn downsampling_type(&self) -> Result<Type, XI_RETURN>

Changes the downsampling type between binning and skipping

pub fn downsampling_type_increment(&self) -> Result<Type, XI_RETURN>

Get the increment for the downsampling_type parameter. See also Self::downsampling_type()

pub fn downsampling_type_minimum(&self) -> Result<Type, XI_RETURN>

Get the minimum for the downsampling_type parameter. See also Self::downsampling_type()

pub fn downsampling_type_maximum(&self) -> Result<Type, XI_RETURN>

Get the maximum for the downsampling_type parameter. See also Self::downsampling_type()

pub fn set_downsampling_type(&mut self, value: Type) -> Result<(), XI_RETURN>

Set the downsampling_type parameter. See also Self::downsampling_type()

pub fn image_data_format(&self) -> Result<Type, XI_RETURN>

Format of the image data

pub fn image_data_format_increment(&self) -> Result<Type, XI_RETURN>

Get the increment for the image_data_format parameter. See also Self::image_data_format()

pub fn image_data_format_minimum(&self) -> Result<Type, XI_RETURN>

Get the minimum for the image_data_format parameter. See also Self::image_data_format()

pub fn image_data_format_maximum(&self) -> Result<Type, XI_RETURN>

Get the maximum for the image_data_format parameter. See also Self::image_data_format()

pub fn set_image_data_format(&mut self, value: Type) -> Result<(), XI_RETURN>

Set the image_data_format parameter. See also Self::image_data_format()

pub fn test_pattern_generator_selector(&self) -> Result<Type, XI_RETURN>

Selects the Test Pattern Generator Engine

pub fn test_pattern_generator_selector_increment( &self, ) -> Result<Type, XI_RETURN>

Get the increment for the test_pattern_generator_selector parameter. See also Self::test_pattern_generator_selector()

pub fn test_pattern_generator_selector_minimum(&self) -> Result<Type, XI_RETURN>

Get the minimum for the test_pattern_generator_selector parameter. See also Self::test_pattern_generator_selector()

pub fn test_pattern_generator_selector_maximum(&self) -> Result<Type, XI_RETURN>

Get the maximum for the test_pattern_generator_selector parameter. See also Self::test_pattern_generator_selector()

pub fn set_test_pattern_generator_selector( &mut self, value: Type, ) -> Result<(), XI_RETURN>

Set the test_pattern_generator_selector parameter. See also Self::test_pattern_generator_selector()

pub fn test_pattern(&self) -> Result<Type, XI_RETURN>

Selects the Test Pattern to be generated by selected Generator Engine

pub fn test_pattern_increment(&self) -> Result<Type, XI_RETURN>

Get the increment for the test_pattern parameter. See also Self::test_pattern()

pub fn test_pattern_minimum(&self) -> Result<Type, XI_RETURN>

Get the minimum for the test_pattern parameter. See also Self::test_pattern()

pub fn test_pattern_maximum(&self) -> Result<Type, XI_RETURN>

Get the maximum for the test_pattern parameter. See also Self::test_pattern()

pub fn set_test_pattern(&mut self, value: Type) -> Result<(), XI_RETURN>

Set the test_pattern parameter. See also Self::test_pattern()

pub fn height(&self) -> Result<u32, XI_RETURN>

Immage ROI height (number of lines)

pub fn height_increment(&self) -> Result<u32, XI_RETURN>

Get the increment for the height parameter. See also Self::height()

pub fn height_minimum(&self) -> Result<u32, XI_RETURN>

Get the minimum for the height parameter. See also Self::height()

pub fn height_maximum(&self) -> Result<u32, XI_RETURN>

Get the maximum for the height parameter. See also Self::height()

pub fn set_height(&mut self, value: u32) -> Result<(), XI_RETURN>

Set the height parameter. See also Self::height()

pub fn width(&self) -> Result<u32, XI_RETURN>

Image ROI width (number of columns)

pub fn width_increment(&self) -> Result<u32, XI_RETURN>

Get the increment for the width parameter. See also Self::width()

pub fn width_minimum(&self) -> Result<u32, XI_RETURN>

Get the minimum for the width parameter. See also Self::width()

pub fn width_maximum(&self) -> Result<u32, XI_RETURN>

Get the maximum for the width parameter. See also Self::width()

pub fn set_width(&mut self, value: u32) -> Result<(), XI_RETURN>

Set the width parameter. See also Self::width()

pub fn offset_x(&self) -> Result<u32, XI_RETURN>

Image ROI offset in the horizontal direction

pub fn offset_x_increment(&self) -> Result<u32, XI_RETURN>

Get the increment for the offset_x parameter. See also Self::offset_x()

pub fn offset_x_minimum(&self) -> Result<u32, XI_RETURN>

Get the minimum for the offset_x parameter. See also Self::offset_x()

pub fn offset_x_maximum(&self) -> Result<u32, XI_RETURN>

Get the maximum for the offset_x parameter. See also Self::offset_x()

pub fn set_offset_x(&mut self, value: u32) -> Result<(), XI_RETURN>

Set the offset_x parameter. See also Self::offset_x()

pub fn offset_y(&self) -> Result<u32, XI_RETURN>

Image ROI offset in the vertical direction

pub fn offset_y_increment(&self) -> Result<u32, XI_RETURN>

Get the increment for the offset_y parameter. See also Self::offset_y()

pub fn offset_y_minimum(&self) -> Result<u32, XI_RETURN>

Get the minimum for the offset_y parameter. See also Self::offset_y()

pub fn offset_y_maximum(&self) -> Result<u32, XI_RETURN>

Get the maximum for the offset_y parameter. See also Self::offset_y()

pub fn set_offset_y(&mut self, value: u32) -> Result<(), XI_RETURN>

Set the offset_y parameter. See also Self::offset_y()

pub fn limit_bandwidth(&self) -> Result<i32, XI_RETURN>

Camera acquisition data-rate limit on transport layer in Megabits per second.

pub fn limit_bandwidth_increment(&self) -> Result<i32, XI_RETURN>

Get the increment for the limit_bandwidth parameter. See also Self::limit_bandwidth()

pub fn limit_bandwidth_minimum(&self) -> Result<i32, XI_RETURN>

Get the minimum for the limit_bandwidth parameter. See also Self::limit_bandwidth()

pub fn limit_bandwidth_maximum(&self) -> Result<i32, XI_RETURN>

Get the maximum for the limit_bandwidth parameter. See also Self::limit_bandwidth()

pub fn set_limit_bandwidth(&mut self, value: i32) -> Result<(), XI_RETURN>

Set the limit_bandwidth parameter. See also Self::limit_bandwidth()

pub fn available_bandwidth(&self) -> Result<i32, XI_RETURN>

Available interface bandwidth measured by automatic bandwidth measurement.

pub fn trg_source(&self) -> Result<Type, XI_RETURN>

Defines the source of trigger

pub fn trg_source_increment(&self) -> Result<Type, XI_RETURN>

Get the increment for the trg_source parameter. See also Self::trg_source()

pub fn trg_source_minimum(&self) -> Result<Type, XI_RETURN>

Get the minimum for the trg_source parameter. See also Self::trg_source()

pub fn trg_source_maximum(&self) -> Result<Type, XI_RETURN>

Get the maximum for the trg_source parameter. See also Self::trg_source()

pub fn set_trg_source(&mut self, value: Type) -> Result<(), XI_RETURN>

Set the trg_source parameter. See also Self::trg_source()

pub fn trg_selector(&self) -> Result<Type, XI_RETURN>

Selects the type of trigger

pub fn trg_selector_increment(&self) -> Result<Type, XI_RETURN>

Get the increment for the trg_selector parameter. See also Self::trg_selector()

pub fn trg_selector_minimum(&self) -> Result<Type, XI_RETURN>

Get the minimum for the trg_selector parameter. See also Self::trg_selector()

pub fn trg_selector_maximum(&self) -> Result<Type, XI_RETURN>

Get the maximum for the trg_selector parameter. See also Self::trg_selector()

pub fn set_trg_selector(&mut self, value: Type) -> Result<(), XI_RETURN>

Set the trg_selector parameter. See also Self::trg_selector()

pub fn trg_overlap(&self) -> Result<Type, XI_RETURN>

Selects the type of trigger overlap

pub fn trg_overlap_increment(&self) -> Result<Type, XI_RETURN>

Get the increment for the trg_overlap parameter. See also Self::trg_overlap()

pub fn trg_overlap_minimum(&self) -> Result<Type, XI_RETURN>

Get the minimum for the trg_overlap parameter. See also Self::trg_overlap()

pub fn trg_overlap_maximum(&self) -> Result<Type, XI_RETURN>

Get the maximum for the trg_overlap parameter. See also Self::trg_overlap()

pub fn set_trg_overlap(&mut self, value: Type) -> Result<(), XI_RETURN>

Set the trg_overlap parameter. See also Self::trg_overlap()

pub fn acq_frame_burst_count(&self) -> Result<u32, XI_RETURN>

Sets the number of frames to be triggered for each trigger signal. This setting is only valid if the trigger selector is set to XI_TRG_SEL_FRAME_BURST_START

pub fn acq_frame_burst_count_increment(&self) -> Result<u32, XI_RETURN>

Get the increment for the acq_frame_burst_count parameter. See also Self::acq_frame_burst_count()

pub fn acq_frame_burst_count_minimum(&self) -> Result<u32, XI_RETURN>

Get the minimum for the acq_frame_burst_count parameter. See also Self::acq_frame_burst_count()

pub fn acq_frame_burst_count_maximum(&self) -> Result<u32, XI_RETURN>

Get the maximum for the acq_frame_burst_count parameter. See also Self::acq_frame_burst_count()

pub fn set_acq_frame_burst_count(&mut self, value: u32) -> Result<(), XI_RETURN>

Set the acq_frame_burst_count parameter. See also Self::acq_frame_burst_count()

pub fn gpi_selector(&self) -> Result<Type, XI_RETURN>

Selects a GPI

pub fn gpi_selector_increment(&self) -> Result<Type, XI_RETURN>

Get the increment for the gpi_selector parameter. See also Self::gpi_selector()

pub fn gpi_selector_minimum(&self) -> Result<Type, XI_RETURN>

Get the minimum for the gpi_selector parameter. See also Self::gpi_selector()

pub fn gpi_selector_maximum(&self) -> Result<Type, XI_RETURN>

Get the maximum for the gpi_selector parameter. See also Self::gpi_selector()

pub fn set_gpi_selector(&mut self, value: Type) -> Result<(), XI_RETURN>

Set the gpi_selector parameter. See also Self::gpi_selector()

pub fn gpi_mode(&self) -> Result<Type, XI_RETURN>

Defines functionality for the selected GPI

pub fn gpi_mode_increment(&self) -> Result<Type, XI_RETURN>

Get the increment for the gpi_mode parameter. See also Self::gpi_mode()

pub fn gpi_mode_minimum(&self) -> Result<Type, XI_RETURN>

Get the minimum for the gpi_mode parameter. See also Self::gpi_mode()

pub fn gpi_mode_maximum(&self) -> Result<Type, XI_RETURN>

Get the maximum for the gpi_mode parameter. See also Self::gpi_mode()

pub fn set_gpi_mode(&mut self, value: Type) -> Result<(), XI_RETURN>

Set the gpi_mode parameter. See also Self::gpi_mode()

pub fn gpo_selector(&self) -> Result<Type, XI_RETURN>

Selects a GPO

pub fn gpo_selector_increment(&self) -> Result<Type, XI_RETURN>

Get the increment for the gpo_selector parameter. See also Self::gpo_selector()

pub fn gpo_selector_minimum(&self) -> Result<Type, XI_RETURN>

Get the minimum for the gpo_selector parameter. See also Self::gpo_selector()

pub fn gpo_selector_maximum(&self) -> Result<Type, XI_RETURN>

Get the maximum for the gpo_selector parameter. See also Self::gpo_selector()

pub fn set_gpo_selector(&mut self, value: Type) -> Result<(), XI_RETURN>

Set the gpo_selector parameter. See also Self::gpo_selector()

pub fn gpo_mode(&self) -> Result<Type, XI_RETURN>

Defines functionality for the selected GPO

pub fn gpo_mode_increment(&self) -> Result<Type, XI_RETURN>

Get the increment for the gpo_mode parameter. See also Self::gpo_mode()

pub fn gpo_mode_minimum(&self) -> Result<Type, XI_RETURN>

Get the minimum for the gpo_mode parameter. See also Self::gpo_mode()

pub fn gpo_mode_maximum(&self) -> Result<Type, XI_RETURN>

Get the maximum for the gpo_mode parameter. See also Self::gpo_mode()

pub fn set_gpo_mode(&mut self, value: Type) -> Result<(), XI_RETURN>

Set the gpo_mode parameter. See also Self::gpo_mode()

pub fn led_selector(&self) -> Result<Type, XI_RETURN>

Selects a LED

pub fn led_selector_increment(&self) -> Result<Type, XI_RETURN>

Get the increment for the led_selector parameter. See also Self::led_selector()

pub fn led_selector_minimum(&self) -> Result<Type, XI_RETURN>

Get the minimum for the led_selector parameter. See also Self::led_selector()

pub fn led_selector_maximum(&self) -> Result<Type, XI_RETURN>

Get the maximum for the led_selector parameter. See also Self::led_selector()

pub fn set_led_selector(&mut self, value: Type) -> Result<(), XI_RETURN>

Set the led_selector parameter. See also Self::led_selector()

pub fn led_mode(&self) -> Result<Type, XI_RETURN>

Defines functionality for the selected LED

pub fn led_mode_increment(&self) -> Result<Type, XI_RETURN>

Get the increment for the led_mode parameter. See also Self::led_mode()

pub fn led_mode_minimum(&self) -> Result<Type, XI_RETURN>

Get the minimum for the led_mode parameter. See also Self::led_mode()

pub fn led_mode_maximum(&self) -> Result<Type, XI_RETURN>

Get the maximum for the led_mode parameter. See also Self::led_mode()

pub fn set_led_mode(&mut self, value: Type) -> Result<(), XI_RETURN>

Set the led_mode parameter. See also Self::led_mode()

pub fn debounce_en(&self) -> Result<Type, XI_RETURN>

Enable or disable signal debounce for selected GPI

pub fn debounce_en_increment(&self) -> Result<Type, XI_RETURN>

Get the increment for the debounce_en parameter. See also Self::debounce_en()

pub fn debounce_en_minimum(&self) -> Result<Type, XI_RETURN>

Get the minimum for the debounce_en parameter. See also Self::debounce_en()

pub fn debounce_en_maximum(&self) -> Result<Type, XI_RETURN>

Get the maximum for the debounce_en parameter. See also Self::debounce_en()

pub fn set_debounce_en(&mut self, value: Type) -> Result<(), XI_RETURN>

Set the debounce_en parameter. See also Self::debounce_en()

pub fn image_user_data(&self) -> Result<u32, XI_RETURN>

Set user data to be stored in the image header

pub fn image_user_data_increment(&self) -> Result<u32, XI_RETURN>

Get the increment for the image_user_data parameter. See also Self::image_user_data()

pub fn image_user_data_minimum(&self) -> Result<u32, XI_RETURN>

Get the minimum for the image_user_data parameter. See also Self::image_user_data()

pub fn image_user_data_maximum(&self) -> Result<u32, XI_RETURN>

Get the maximum for the image_user_data parameter. See also Self::image_user_data()

pub fn set_image_user_data(&mut self, value: u32) -> Result<(), XI_RETURN>

Set the image_user_data parameter. See also Self::image_user_data()

pub fn sensor_data_bit_depth(&self) -> Result<Type, XI_RETURN>

Set the bit depth for the ADCs on the sensor

Examples
let mut cam = xiapi::open_device(None)?;
cam.set_image_data_format(XI_RAW16)?;
cam.set_sensor_data_bit_depth(XI_BPP_12)?;
cam.set_output_data_bit_depth(XI_BPP_12)?;
cam.set_image_data_bit_depth(XI_BPP_12)?;
}
pub fn sensor_data_bit_depth_increment(&self) -> Result<Type, XI_RETURN>

Get the increment for the sensor_data_bit_depth parameter. See also Self::sensor_data_bit_depth()

pub fn sensor_data_bit_depth_minimum(&self) -> Result<Type, XI_RETURN>

Get the minimum for the sensor_data_bit_depth parameter. See also Self::sensor_data_bit_depth()

pub fn sensor_data_bit_depth_maximum(&self) -> Result<Type, XI_RETURN>

Get the maximum for the sensor_data_bit_depth parameter. See also Self::sensor_data_bit_depth()

pub fn set_sensor_data_bit_depth( &mut self, value: Type, ) -> Result<(), XI_RETURN>

Set the sensor_data_bit_depth parameter. See also Self::sensor_data_bit_depth()

pub fn output_data_bit_depth(&self) -> Result<Type, XI_RETURN>

Set the bit depth send from the camera to the PC

pub fn output_data_bit_depth_increment(&self) -> Result<Type, XI_RETURN>

Get the increment for the output_data_bit_depth parameter. See also Self::output_data_bit_depth()

pub fn output_data_bit_depth_minimum(&self) -> Result<Type, XI_RETURN>

Get the minimum for the output_data_bit_depth parameter. See also Self::output_data_bit_depth()

pub fn output_data_bit_depth_maximum(&self) -> Result<Type, XI_RETURN>

Get the maximum for the output_data_bit_depth parameter. See also Self::output_data_bit_depth()

pub fn set_output_data_bit_depth( &mut self, value: Type, ) -> Result<(), XI_RETURN>

Set the output_data_bit_depth parameter. See also Self::output_data_bit_depth()

pub fn image_data_bit_depth(&self) -> Result<Type, XI_RETURN>

Bit depth of the image returned by [Self::next_image()]

pub fn image_data_bit_depth_increment(&self) -> Result<Type, XI_RETURN>

Get the increment for the image_data_bit_depth parameter. See also Self::image_data_bit_depth()

pub fn image_data_bit_depth_minimum(&self) -> Result<Type, XI_RETURN>

Get the minimum for the image_data_bit_depth parameter. See also Self::image_data_bit_depth()

pub fn image_data_bit_depth_maximum(&self) -> Result<Type, XI_RETURN>

Get the maximum for the image_data_bit_depth parameter. See also Self::image_data_bit_depth()

pub fn set_image_data_bit_depth(&mut self, value: Type) -> Result<(), XI_RETURN>

Set the image_data_bit_depth parameter. See also Self::image_data_bit_depth()

pub fn column_fpn_correction(&self) -> Result<Type, XI_RETURN>

Enable column fpn correction in camera

pub fn column_fpn_correction_increment(&self) -> Result<Type, XI_RETURN>

Get the increment for the column_fpn_correction parameter. See also Self::column_fpn_correction()

pub fn column_fpn_correction_minimum(&self) -> Result<Type, XI_RETURN>

Get the minimum for the column_fpn_correction parameter. See also Self::column_fpn_correction()

pub fn column_fpn_correction_maximum(&self) -> Result<Type, XI_RETURN>

Get the maximum for the column_fpn_correction parameter. See also Self::column_fpn_correction()

pub fn set_column_fpn_correction( &mut self, value: Type, ) -> Result<(), XI_RETURN>

Set the column_fpn_correction parameter. See also Self::column_fpn_correction()

pub fn row_fpn_correction(&self) -> Result<Type, XI_RETURN>

Enable row fpn correction in camera

pub fn row_fpn_correction_increment(&self) -> Result<Type, XI_RETURN>

Get the increment for the row_fpn_correction parameter. See also Self::row_fpn_correction()

pub fn row_fpn_correction_minimum(&self) -> Result<Type, XI_RETURN>

Get the minimum for the row_fpn_correction parameter. See also Self::row_fpn_correction()

pub fn row_fpn_correction_maximum(&self) -> Result<Type, XI_RETURN>

Get the maximum for the row_fpn_correction parameter. See also Self::row_fpn_correction()

pub fn set_row_fpn_correction(&mut self, value: Type) -> Result<(), XI_RETURN>

Set the row_fpn_correction parameter. See also Self::row_fpn_correction()

pub fn column_black_offset_correction(&self) -> Result<Type, XI_RETURN>

Enable column black offset correction

pub fn column_black_offset_correction_increment( &self, ) -> Result<Type, XI_RETURN>

Get the increment for the column_black_offset_correction parameter. See also Self::column_black_offset_correction()

pub fn column_black_offset_correction_minimum(&self) -> Result<Type, XI_RETURN>

Get the minimum for the column_black_offset_correction parameter. See also Self::column_black_offset_correction()

pub fn column_black_offset_correction_maximum(&self) -> Result<Type, XI_RETURN>

Get the maximum for the column_black_offset_correction parameter. See also Self::column_black_offset_correction()

pub fn set_column_black_offset_correction( &mut self, value: Type, ) -> Result<(), XI_RETURN>

Set the column_black_offset_correction parameter. See also Self::column_black_offset_correction()

pub fn row_black_offset_correction(&self) -> Result<Type, XI_RETURN>

Enable row black offset correction

pub fn row_black_offset_correction_increment(&self) -> Result<Type, XI_RETURN>

Get the increment for the row_black_offset_correction parameter. See also Self::row_black_offset_correction()

pub fn row_black_offset_correction_minimum(&self) -> Result<Type, XI_RETURN>

Get the minimum for the row_black_offset_correction parameter. See also Self::row_black_offset_correction()

pub fn row_black_offset_correction_maximum(&self) -> Result<Type, XI_RETURN>

Get the maximum for the row_black_offset_correction parameter. See also Self::row_black_offset_correction()

pub fn set_row_black_offset_correction( &mut self, value: Type, ) -> Result<(), XI_RETURN>

Set the row_black_offset_correction parameter. See also Self::row_black_offset_correction()

pub fn counter_selector(&self) -> Result<Type, XI_RETURN>

Select the frame counter to read

pub fn counter_selector_increment(&self) -> Result<Type, XI_RETURN>

Get the increment for the counter_selector parameter. See also Self::counter_selector()

pub fn counter_selector_minimum(&self) -> Result<Type, XI_RETURN>

Get the minimum for the counter_selector parameter. See also Self::counter_selector()

pub fn counter_selector_maximum(&self) -> Result<Type, XI_RETURN>

Get the maximum for the counter_selector parameter. See also Self::counter_selector()

pub fn set_counter_selector(&mut self, value: Type) -> Result<(), XI_RETURN>

Set the counter_selector parameter. See also Self::counter_selector()

pub fn counter_value(&self) -> Result<i32, XI_RETURN>

Read the value of a frame counter selected with Self::set_counter_selector

pub fn sensor_feature_selector(&self) -> Result<Type, XI_RETURN>

Select a sensor specific feature

pub fn sensor_feature_selector_increment(&self) -> Result<Type, XI_RETURN>

Get the increment for the sensor_feature_selector parameter. See also Self::sensor_feature_selector()

pub fn sensor_feature_selector_minimum(&self) -> Result<Type, XI_RETURN>

Get the minimum for the sensor_feature_selector parameter. See also Self::sensor_feature_selector()

pub fn sensor_feature_selector_maximum(&self) -> Result<Type, XI_RETURN>

Get the maximum for the sensor_feature_selector parameter. See also Self::sensor_feature_selector()

pub fn set_sensor_feature_selector( &mut self, value: Type, ) -> Result<(), XI_RETURN>

Set the sensor_feature_selector parameter. See also Self::sensor_feature_selector()

pub fn sensor_feature_value(&self) -> Result<i32, XI_RETURN>

Set a value for the feature selected with Self::set_sensor_feature_selector

pub fn sensor_feature_value_increment(&self) -> Result<i32, XI_RETURN>

Get the increment for the sensor_feature_value parameter. See also Self::sensor_feature_value()

pub fn sensor_feature_value_minimum(&self) -> Result<i32, XI_RETURN>

Get the minimum for the sensor_feature_value parameter. See also Self::sensor_feature_value()

pub fn sensor_feature_value_maximum(&self) -> Result<i32, XI_RETURN>

Get the maximum for the sensor_feature_value parameter. See also Self::sensor_feature_value()

pub fn set_sensor_feature_value(&mut self, value: i32) -> Result<(), XI_RETURN>

Set the sensor_feature_value parameter. See also Self::sensor_feature_value()

pub fn sensor_clock_freq_hz(&self) -> Result<f32, XI_RETURN>

Read the sensor clock frequency in Hz

pub fn buffer_policy(&self) -> Result<i32, XI_RETURN>

Data move policy

pub fn buffer_policy_increment(&self) -> Result<i32, XI_RETURN>

Get the increment for the buffer_policy parameter. See also Self::buffer_policy()

pub fn buffer_policy_minimum(&self) -> Result<i32, XI_RETURN>

Get the minimum for the buffer_policy parameter. See also Self::buffer_policy()

pub fn buffer_policy_maximum(&self) -> Result<i32, XI_RETURN>

Get the maximum for the buffer_policy parameter. See also Self::buffer_policy()

pub fn set_buffer_policy(&mut self, value: i32) -> Result<(), XI_RETURN>

Set the buffer_policy parameter. See also Self::buffer_policy()

pub fn auto_wb(&self) -> Result<Type, XI_RETURN>

Auto white balance mode.

pub fn auto_wb_increment(&self) -> Result<Type, XI_RETURN>

Get the increment for the auto_wb parameter. See also Self::auto_wb()

pub fn auto_wb_minimum(&self) -> Result<Type, XI_RETURN>

Get the minimum for the auto_wb parameter. See also Self::auto_wb()

pub fn auto_wb_maximum(&self) -> Result<Type, XI_RETURN>

Get the maximum for the auto_wb parameter. See also Self::auto_wb()

pub fn set_auto_wb(&mut self, value: Type) -> Result<(), XI_RETURN>

Set the auto_wb parameter. See also Self::auto_wb()

pub fn wb_kr(&self) -> Result<f32, XI_RETURN>

White balance Red coefficient.

pub fn wb_kr_increment(&self) -> Result<f32, XI_RETURN>

Get the increment for the wb_kr parameter. See also Self::wb_kr()

pub fn wb_kr_minimum(&self) -> Result<f32, XI_RETURN>

Get the minimum for the wb_kr parameter. See also Self::wb_kr()

pub fn wb_kr_maximum(&self) -> Result<f32, XI_RETURN>

Get the maximum for the wb_kr parameter. See also Self::wb_kr()

pub fn set_wb_kr(&mut self, value: f32) -> Result<(), XI_RETURN>

Set the wb_kr parameter. See also Self::wb_kr()

pub fn wb_kg(&self) -> Result<f32, XI_RETURN>

White balance Green coefficient.

pub fn wb_kg_increment(&self) -> Result<f32, XI_RETURN>

Get the increment for the wb_kg parameter. See also Self::wb_kg()

pub fn wb_kg_minimum(&self) -> Result<f32, XI_RETURN>

Get the minimum for the wb_kg parameter. See also Self::wb_kg()

pub fn wb_kg_maximum(&self) -> Result<f32, XI_RETURN>

Get the maximum for the wb_kg parameter. See also Self::wb_kg()

pub fn set_wb_kg(&mut self, value: f32) -> Result<(), XI_RETURN>

Set the wb_kg parameter. See also Self::wb_kg()

pub fn wb_kb(&self) -> Result<f32, XI_RETURN>

White balance Blue coefficient.

pub fn wb_kb_increment(&self) -> Result<f32, XI_RETURN>

Get the increment for the wb_kb parameter. See also Self::wb_kb()

pub fn wb_kb_minimum(&self) -> Result<f32, XI_RETURN>

Get the minimum for the wb_kb parameter. See also Self::wb_kb()

pub fn wb_kb_maximum(&self) -> Result<f32, XI_RETURN>

Get the maximum for the wb_kb parameter. See also Self::wb_kb()

pub fn set_wb_kb(&mut self, value: f32) -> Result<(), XI_RETURN>

Set the wb_kb parameter. See also Self::wb_kb()

pub fn recent_frame(&self) -> Result<Type, XI_RETURN>

Recent Frame mode.

pub fn recent_frame_increment(&self) -> Result<Type, XI_RETURN>

Get the increment for the recent_frame parameter. See also Self::recent_frame()

pub fn recent_frame_minimum(&self) -> Result<Type, XI_RETURN>

Get the minimum for the recent_frame parameter. See also Self::recent_frame()

pub fn recent_frame_maximum(&self) -> Result<Type, XI_RETURN>

Get the maximum for the recent_frame parameter. See also Self::recent_frame()

pub fn set_recent_frame(&mut self, value: Type) -> Result<(), XI_RETURN>

Set the recent_frame parameter. See also Self::recent_frame()